@@ -1,7 +1,7 @@
 import asyncio
 
 from arpakitlib.ar_base_worker_util import safe_run_workers_in_background, SafeRunInBackgroundModes
-from project.core.util import setup_logging
+from project.core.setup_logging import setup_logging
 from project.operation_execution.operation_executor_worker import OperationExecutorWorker
 from project.sqlalchemy_db_.sqlalchemy_db import get_cached_sqlalchemy_db
 
