@@ -1,5 +1,7 @@
 from typing import Any
 
+from pydantic import Field
+
 from project.api.schema.common import BaseSO
 
 
@@ -8,4 +10,5 @@ class ErrorCommonSO(BaseSO):
     error_code: str | None = None
     error_specification_code: str | None = None
     error_description: str | None = None
-    error_data: dict[str, Any] = {}
+    error_description_data: dict[str, Any] = Field(default_factory=dict)
+    error_data: dict[str, Any] = Field(default_factory=dict)
